scoretools.Tuplet
=================

.. autoclass:: abjad.tools.scoretools.Tuplet.Tuplet

Lineage
-------

.. graphviz::

   digraph InheritanceGraph {
       graph [background=transparent,
           color=lightslategrey,
           fontname=Arial,
           outputorder=edgesfirst,
           overlap=prism,
           penwidth=2,
           rankdir=LR,
           root="__builtin__.object",
           splines=spline,
           style="dotted, rounded"];
       node [colorscheme=pastel19,
           fontname=Arial,
           fontsize=12,
           penwidth=2,
           style="filled, rounded"];
       edge [color=lightsteelblue2,
           penwidth=2];
       subgraph cluster___builtin__ {
           graph [label=__builtin__];
           "__builtin__.object" [color=1,
               group=0,
               label=object,
               shape=box];
       }
       subgraph cluster_abctools {
           graph [label=abctools];
           "abctools.AbjadObject" [color=2,
               group=1,
               label=AbjadObject,
               shape=box];
           "abctools.AbjadObject.AbstractBase" [color=2,
               group=1,
               label=AbstractBase,
               shape=box];
           "abctools.AbjadObject.AbstractBase" -> "abctools.AbjadObject";
       }
       subgraph cluster_scoretools {
           graph [label=scoretools];
           "scoretools.Component" [color=3,
               group=2,
               label=Component,
               shape=oval,
               style=bold];
           "scoretools.Container" [color=3,
               group=2,
               label=Container,
               shape=box];
           "scoretools.FixedDurationTuplet" [color=3,
               group=2,
               label=FixedDurationTuplet,
               shape=box];
           "scoretools.Tuplet" [color=black,
               fontcolor=white,
               group=2,
               label=<<B>Tuplet</B>>,
               shape=box,
               style="filled, rounded"];
           "scoretools.Component" -> "scoretools.Container";
           "scoretools.Container" -> "scoretools.Tuplet";
           "scoretools.Tuplet" -> "scoretools.FixedDurationTuplet";
       }
       "__builtin__.object" -> "abctools.AbjadObject.AbstractBase";
       "abctools.AbjadObject" -> "scoretools.Component";
   }

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.scoretools.Tuplet.Tuplet.append
      ~abjad.tools.scoretools.Tuplet.Tuplet.extend
      ~abjad.tools.scoretools.Tuplet.Tuplet.force_fraction
      ~abjad.tools.scoretools.Tuplet.Tuplet.force_times_command
      ~abjad.tools.scoretools.Tuplet.Tuplet.from_duration_and_ratio
      ~abjad.tools.scoretools.Tuplet.Tuplet.from_leaf_and_ratio
      ~abjad.tools.scoretools.Tuplet.Tuplet.from_nonreduced_ratio_and_nonreduced_fraction
      ~abjad.tools.scoretools.Tuplet.Tuplet.implied_prolation
      ~abjad.tools.scoretools.Tuplet.Tuplet.index
      ~abjad.tools.scoretools.Tuplet.Tuplet.insert
      ~abjad.tools.scoretools.Tuplet.Tuplet.is_augmentation
      ~abjad.tools.scoretools.Tuplet.Tuplet.is_diminution
      ~abjad.tools.scoretools.Tuplet.Tuplet.is_invisible
      ~abjad.tools.scoretools.Tuplet.Tuplet.is_simultaneous
      ~abjad.tools.scoretools.Tuplet.Tuplet.is_trivial
      ~abjad.tools.scoretools.Tuplet.Tuplet.multiplied_duration
      ~abjad.tools.scoretools.Tuplet.Tuplet.multiplier
      ~abjad.tools.scoretools.Tuplet.Tuplet.name
      ~abjad.tools.scoretools.Tuplet.Tuplet.pop
      ~abjad.tools.scoretools.Tuplet.Tuplet.preferred_denominator
      ~abjad.tools.scoretools.Tuplet.Tuplet.remove
      ~abjad.tools.scoretools.Tuplet.Tuplet.reverse
      ~abjad.tools.scoretools.Tuplet.Tuplet.select_leaves
      ~abjad.tools.scoretools.Tuplet.Tuplet.set_minimum_denominator
      ~abjad.tools.scoretools.Tuplet.Tuplet.to_fixed_duration_tuplet
      ~abjad.tools.scoretools.Tuplet.Tuplet.toggle_prolation
      ~abjad.tools.scoretools.Tuplet.Tuplet.__contains__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__copy__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__delitem__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__eq__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__format__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__getitem__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__graph__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__hash__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__illustrate__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__len__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__mul__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__ne__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__repr__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__rmul__
      ~abjad.tools.scoretools.Tuplet.Tuplet.__setitem__

Bases
-----

- :py:class:`scoretools.Container <abjad.tools.scoretools.Container.Container>`

- :py:class:`scoretools.Component <abjad.tools.scoretools.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.is_augmentation
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.is_diminution
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.is_trivial
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.multiplied_duration
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.force_fraction
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.force_times_command
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.is_invisible
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.is_simultaneous
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.multiplier
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.name
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Tuplet.Tuplet.preferred_denominator
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.append
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.index
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.remove
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.reverse
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.select_leaves
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.set_minimum_denominator
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.to_fixed_duration_tuplet
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.toggle_prolation
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.from_duration_and_ratio
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.from_leaf_and_ratio
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.from_nonreduced_ratio_and_nonreduced_fraction
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__copy__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__format__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__graph__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__hash__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__illustrate__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Tuplet.Tuplet.__setitem__
   :noindex:
